@@ -20,10 +20,12 @@ User = get_user_model()
 class Notification(models.Model):
     SIGN_COMPANY = 'SIGN_COMPANY'
     SIMPLE_OK = 'SIMPLE_OK'
+    RELEASE_NOTES = 'RELEASE_NOTES'
 
     NOTIFICATION_CHOICES = (
         (SIGN_COMPANY, 'SIGN_COMPANY'),
-        (SIMPLE_OK, 'SIMPLE_OK')
+        (SIMPLE_OK, 'SIMPLE_OK'),
+        (RELEASE_NOTES, 'RELEASE_NOTES'),
     )
     external_id = models.IntegerField(
         null=True,
